import setuptools

setuptools.setup(
    name="motional_ml_core",
    version="0.0.0",
    author="Motional",
    author_email="devops@motional.com",
    description="motional_ml_core",
    long_description="motional_ml_core",
    long_description_content_type="text/markdown",
    url="https://motional.com/",
    packages=[],
    python_requires='>=5',
)
